==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance.md <==
# AwsTrustedAdvisorChecklistPerformance


```text
aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance
```

```text
include('aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance')
```



| Illustration | AwsTrustedAdvisorChecklistPerformance | AwsTrustedAdvisorChecklistPerformanceCard | AwsTrustedAdvisorChecklistPerformanceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance.png) | ![illustration for AwsTrustedAdvisorChecklistPerformance](../../../aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance.Local.png) | ![illustration for AwsTrustedAdvisorChecklistPerformanceCard](../../../aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformanceCard.Local.png) | ![illustration for AwsTrustedAdvisorChecklistPerformanceGroup](../../../aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformanceGroup.Local.png) |




## AwsTrustedAdvisorChecklistPerformance

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistPerformance
include('aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance')

' renders the element
AwsTrustedAdvisorChecklistPerformance('AwsTrustedAdvisorChecklistPerformance', 'Aws Trusted Advisor Checklist Performance', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistPerformance
include('aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance')

' renders the element
AwsTrustedAdvisorChecklistPerformance('AwsTrustedAdvisorChecklistPerformance', 'Aws Trusted Advisor Checklist Performance', 'an optional tech label')
@enduml
```

## AwsTrustedAdvisorChecklistPerformanceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistPerformanceCard
include('aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance')

' renders the element
AwsTrustedAdvisorChecklistPerformanceCard('AwsTrustedAdvisorChecklistPerformanceCard', 'Aws Trusted Advisor Checklist Performance Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistPerformanceCard
include('aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance')

' renders the element
AwsTrustedAdvisorChecklistPerformanceCard('AwsTrustedAdvisorChecklistPerformanceCard', 'Aws Trusted Advisor Checklist Performance Card', 'an optional description')
@enduml
```

## AwsTrustedAdvisorChecklistPerformanceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistPerformanceGroup
include('aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance')

' renders the element
AwsTrustedAdvisorChecklistPerformanceGroup('AwsTrustedAdvisorChecklistPerformanceGroup', 'Aws Trusted Advisor Checklist Performance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistPerformanceGroup
include('aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance')

' renders the element
AwsTrustedAdvisorChecklistPerformanceGroup('AwsTrustedAdvisorChecklistPerformanceGroup', 'Aws Trusted Advisor Checklist Performance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance.md <==
# AwsTrustedAdvisorChecklistPerformance


```text
aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance
```

```text
include('aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance')
```



| Illustration | AwsTrustedAdvisorChecklistPerformance | AwsTrustedAdvisorChecklistPerformanceCard | AwsTrustedAdvisorChecklistPerformanceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance.png) | ![illustration for AwsTrustedAdvisorChecklistPerformance](../../../aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance.Local.png) | ![illustration for AwsTrustedAdvisorChecklistPerformanceCard](../../../aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformanceCard.Local.png) | ![illustration for AwsTrustedAdvisorChecklistPerformanceGroup](../../../aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformanceGroup.Local.png) |




## AwsTrustedAdvisorChecklistPerformance

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistPerformance
include('aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance')

' renders the element
AwsTrustedAdvisorChecklistPerformance('AwsTrustedAdvisorChecklistPerformance', 'Aws Trusted Advisor Checklist Performance', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistPerformance
include('aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance')

' renders the element
AwsTrustedAdvisorChecklistPerformance('AwsTrustedAdvisorChecklistPerformance', 'Aws Trusted Advisor Checklist Performance', 'an optional tech label')
@enduml
```

## AwsTrustedAdvisorChecklistPerformanceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistPerformanceCard
include('aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance')

' renders the element
AwsTrustedAdvisorChecklistPerformanceCard('AwsTrustedAdvisorChecklistPerformanceCard', 'Aws Trusted Advisor Checklist Performance Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistPerformanceCard
include('aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance')

' renders the element
AwsTrustedAdvisorChecklistPerformanceCard('AwsTrustedAdvisorChecklistPerformanceCard', 'Aws Trusted Advisor Checklist Performance Card', 'an optional description')
@enduml
```

## AwsTrustedAdvisorChecklistPerformanceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistPerformanceGroup
include('aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance')

' renders the element
AwsTrustedAdvisorChecklistPerformanceGroup('AwsTrustedAdvisorChecklistPerformanceGroup', 'Aws Trusted Advisor Checklist Performance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistPerformanceGroup
include('aws-q3-2021/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistPerformance')

' renders the element
AwsTrustedAdvisorChecklistPerformanceGroup('AwsTrustedAdvisorChecklistPerformanceGroup', 'Aws Trusted Advisor Checklist Performance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
